==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Files/packet__router_8hpp.md <==
---
title: llarp/vpn/packet_router.hpp

---

# llarp/vpn/packet_router.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::vpn](Namespaces/namespacellarp_1_1vpn.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::vpn::Layer4Handler](Classes/structllarp_1_1vpn_1_1Layer4Handler.md)**  |
| class | **[llarp::vpn::PacketRouter](Classes/classllarp_1_1vpn_1_1PacketRouter.md)**  |




## Source code

```cpp
#pragma once
#include <llarp/net/net_int.hpp>
#include <llarp/net/ip_packet.hpp>
#include <functional>
#include <unordered_map>

namespace llarp::vpn
{
  using PacketHandlerFunc = std::function<void(llarp::net::IPPacket)>;

  struct Layer4Handler
  {
    virtual ~Layer4Handler() = default;

    virtual void
    HandleIPPacket(llarp::net::IPPacket pkt) = 0;

    virtual void AddSubHandler(nuint16_t, PacketHandlerFunc){};
  };
  class PacketRouter
  {
    PacketHandlerFunc m_BaseHandler;
    std::unordered_map<uint8_t, std::unique_ptr<Layer4Handler>> m_IPProtoHandler;

   public:
    explicit PacketRouter(PacketHandlerFunc baseHandler);

    void
    HandleIPPacket(llarp::net::IPPacket pkt);

    void
    AddIProtoHandler(uint8_t proto, PacketHandlerFunc func);

    void
    AddUDPHandler(huint16_t localport, PacketHandlerFunc func);

    void
    RemoveUDPHandler(huint16_t localport);
  };
}  // namespace llarp::vpn
```


-------------------------------

Updated on 2022-05-31 at 02:25:21 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Files/packet__router_8hpp.md <==
---
title: llarp/vpn/packet_router.hpp

---

# llarp/vpn/packet_router.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::vpn](Namespaces/namespacellarp_1_1vpn.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::vpn::PacketRouter](Classes/classllarp_1_1vpn_1_1PacketRouter.md)**  |
| struct | **[llarp::vpn::Layer4Handler](Classes/structllarp_1_1vpn_1_1Layer4Handler.md)**  |




## Source code

```cpp
#pragma once
#include <llarp/net/net_int.hpp>
#include <llarp/net/ip_packet.hpp>
#include <functional>
#include <unordered_map>

namespace llarp::vpn
{
  using PacketHandlerFunc_t = std::function<void(llarp::net::IPPacket)>;

  struct Layer4Handler;

  class PacketRouter
  {
    PacketHandlerFunc_t m_BaseHandler;
    std::unordered_map<uint8_t, std::unique_ptr<Layer4Handler>> m_IPProtoHandler;

   public:
    explicit PacketRouter(PacketHandlerFunc_t baseHandler);

    void
    HandleIPPacket(llarp::net::IPPacket pkt);

    void
    AddIProtoHandler(uint8_t proto, PacketHandlerFunc_t func);

    void
    AddUDPHandler(huint16_t localport, PacketHandlerFunc_t func);

    void
    RemoveUDPHandler(huint16_t localport);
  };

  struct Layer4Handler
  {
    virtual ~Layer4Handler() = default;

    virtual void
    HandleIPPacket(llarp::net::IPPacket pkt) = 0;

    virtual void AddSubHandler(nuint16_t, PacketHandlerFunc_t){};
  };

}  // namespace llarp::vpn
```


-------------------------------

Updated on 2022-11-29 at 18:11:27 +0000
